#pragma once

typedef BOOL (WINAPI *PFNSNMPEXTENSIONINIT)	(DWORD, HANDLE *, AsnObjectIdentifier *);
typedef BOOL (WINAPI *PFNSNMPEXTENSIONQUERY)(BYTE, SnmpVarBindList *, AsnInteger32 *, AsnInteger32 *);

//===========================================================================
// Summary:
//     arpTable structure: Used to store ARP entries.
//===========================================================================

typedef struct
{
	unsigned long	Type;			// Type: 3:Dynamic, 4:Static
	unsigned char	IPAddress[4];	// IP Address
	unsigned char	MACAddress[6];	// MAC Address
} arpTable;


class CARP
{
private:
	HMODULE					hMIBLibrary;			// Handle for library: inetmib1.dll

	PFNSNMPEXTENSIONINIT	pfnSnmpExtensionInit;	// Pointer to function: SnmpExtensionInit
	PFNSNMPEXTENSIONQUERY	pfnSnmpExtensionQuery;	// Pointer to function: SnmpExtensionQuery

	BOOL					bInitialized;
public:
	CARP(void);
	~CARP(void);

	//-----------------------------------------------------------------------
	// Summary:
	//		Read ARP table for specific NIC interface.
	// Parameters:
	//		pTable			- Pointer to array of arpTable struct
	//		TableLength		- Length of the array
	//		AdapterIndex	- NIC Adapter index number
	// Returns:
	//		Number of read ARP entries
	//-----------------------------------------------------------------------
	int		GetEntries(arpTable* pTable, int TableLength, int AdapterIndex);
	
	//-----------------------------------------------------------------------
	// Summary:
	//		Add/Modify/Remove ARP entry for specific NIC interface.
	// Parameters:
	//	IPAddress 		- Array of 4 BYTES, 4 octs of IP Address
	//	MACAddress		- Array of 4 BYTES, 6 octs of MAC Address
	//	Type			- Entry type (2:Remove, 3:Dynamic, 4:Static)
	//	AdapterIndex	- NIC Adapter index number
	// Returns:
	//		TRUE if set successfully, FALSE otherwise.
	//-----------------------------------------------------------------------
	BOOL	EditEntry(unsigned char IPAddress[4], unsigned char MACAddress[6], unsigned long Type, int AdapterIndex);

};
